==> cloudt-platform-service-0.2.3-20230804.023450-1-sources.jar: com/elitescloud/cloudt/platform/service/repo/SysPlatformUdcValueRepoProc.java <==
package com.elitescloud.cloudt.platform.service.repo;

import com.elitescloud.boot.common.param.CodeNameParam;
import com.elitescloud.boot.jpa.common.BaseRepoProc;
import com.elitescloud.cloudt.platform.model.entity.QSysPlatformUdcValueDO;
import com.elitescloud.cloudt.platform.model.entity.SysPlatformUdcValueDO;
import com.querydsl.core.types.Projections;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import javax.validation.constraints.NotBlank;
import java.util.List;

@Repository
public class SysPlatformUdcValueRepoProc extends BaseRepoProc<SysPlatformUdcValueDO> {
    private static final QSysPlatformUdcValueDO QDO = QSysPlatformUdcValueDO.sysPlatformUdcValueDO;

    public SysPlatformUdcValueRepoProc() {
        super(QDO);
    }

    @Transactional(rollbackFor = Exception.class)
    public void delete(@NotBlank String appCode, @NotBlank String udcCode, @NotBlank String udcValue, Boolean allowDefault) {
        var predicate = PredicateBuilder.builder()
                .andEq(QDO.udcCode, udcValue)
                .andEq(QDO.appCode, appCode)
                .andEq(QDO.udcValueCode, udcValue)
                .andEq(QDO.allowDefault, allowDefault)
                .build();
    }

    /**
     * 根据应用编码删除
     *
     * @param appCode 应用编码
     */
    public void deleteByApp(@NotBlank String appCode) {
        super.deleteByValue(QDO.appCode, appCode);
    }

    /**
     * 查询值列表
     *
     * @param appCode 应用编码
     * @param udcCode UDC编码
     * @param enabled 启用状态
     * @return 值列表
     */
    public List<SysPlatformUdcValueDO> queryValue(@NotBlank String appCode, @NotBlank String udcCode, Boolean enabled) {
        var predicate = PredicateBuilder.builder()
                .andEq(true, QDO.udcCode, udcCode)
                .andEq(true, QDO.appCode, appCode)
                .andEq(enabled != null, QDO.allowStart, enabled)
                .build();
        return super.getList(predicate);
    }

    /**
     * 获取值列表
     *
     * @param appCode
     * @param udcCode
     * @return
     */
    public List<CodeNameParam> getValueList(@NotBlank String appCode, @NotBlank String udcCode, Boolean enabled) {
        var predicate = PredicateBuilder.builder()
                .andEq(true, QDO.udcCode, udcCode)
                .andEq(true, QDO.appCode, appCode)
                .andEq(enabled != null, QDO.allowStart, enabled)
                .build();
        return jpaQueryFactory.select(Projections.bean(CodeNameParam.class, QDO.udcValueCode.as("code"), QDO.udcValueName.as("name")))
                .from(QDO)
                .where(predicate)
                .orderBy(QDO.udcOrder.asc())
                .fetch();
    }
}

==> cloudt-platform-service-0.2.10-20240422.035743-1-sources.jar: com/elitescloud/cloudt/platform/service/repo/SysPlatformUdcValueRepoProc.java <==
package com.elitescloud.cloudt.platform.service.repo;

import com.elitescloud.boot.common.param.CodeNameParam;
import com.elitescloud.boot.jpa.common.BaseRepoProc;
import com.elitescloud.cloudt.platform.model.entity.QSysPlatformUdcValueDO;
import com.elitescloud.cloudt.platform.model.entity.SysPlatformUdcValueDO;
import com.elitescloud.cloudt.platform.model.vo.SysPlatformUdcValueMngVO;
import com.querydsl.core.types.Projections;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

import javax.validation.constraints.NotBlank;
import java.util.HashMap;
import java.util.List;

@Repository
public class SysPlatformUdcValueRepoProc extends BaseRepoProc<SysPlatformUdcValueDO> {
    private static final QSysPlatformUdcValueDO QDO = QSysPlatformUdcValueDO.sysPlatformUdcValueDO;

    public SysPlatformUdcValueRepoProc() {
        super(QDO);
    }

    @Transactional(rollbackFor = Exception.class)
    public void delete(@NotBlank String appCode, @NotBlank String udcCode, @NotBlank String udcValue, Boolean allowDefault) {
        var predicate = PredicateBuilder.builder()
                .andEq(QDO.udcCode, udcValue)
                .andEq(QDO.appCode, appCode)
                .andEq(QDO.udcValueCode, udcValue)
                .andEq(QDO.allowDefault, allowDefault)
                .build();
    }

    /**
     * 根据应用编码删除
     *
     * @param appCode 应用编码
     */
    public void deleteByApp(@NotBlank String appCode) {
        super.deleteByValue(QDO.appCode, appCode);
    }

    /**
     * 查询值列表
     *
     * @param appCode 应用编码
     * @param udcCode UDC编码
     * @param enabled 启用状态
     * @return 值列表
     */
    public List<SysPlatformUdcValueDO> queryValue(@NotBlank String appCode, @NotBlank String udcCode, Boolean enabled) {
        var predicate = PredicateBuilder.builder()
                .andEq(true, QDO.udcCode, udcCode)
                .andEq(true, QDO.appCode, appCode)
                .andEq(enabled != null, QDO.allowStart, enabled)
                .build();
        return super.getList(predicate);
    }

    /**
     * 获取值列表
     *
     * @param appCode
     * @param udcCode
     * @return
     */
    public List<CodeNameParam> getValueList(@NotBlank String appCode, @NotBlank String udcCode, Boolean enabled) {
        var predicate = PredicateBuilder.builder()
                .andEq(true, QDO.udcCode, udcCode)
                .andEq(true, QDO.appCode, appCode)
                .andEq(enabled != null, QDO.allowStart, enabled)
                .build();
        return jpaQueryFactory.select(Projections.bean(CodeNameParam.class, QDO.udcValueCode.as("code"), QDO.udcValueName.as("name")))
                .from(QDO)
                .where(predicate)
                .orderBy(QDO.udcOrder.asc())
                .fetch();
    }

    public List<SysPlatformUdcValueMngVO> queryUdcValueList(HashMap<String,Object> param) {
        return jpaQueryFactory.select(Projections.bean(SysPlatformUdcValueMngVO.class,
                        QDO.id,
                        QDO.udcCode,
                        QDO.udcValueName,
                        QDO.udcValueCode,
                        QDO.appCode,
                        //QDO.valueAliasName,
                        QDO.udcOrder,
                        QDO.allowDefault,
                        QDO.allowStart,
                        QDO.udcValueDescribe,
                        QDO.parentUdcValueCode,
                        QDO.tenantId,
                        QDO.remark,
                        QDO.createTime,
                        QDO.creator,
                        QDO.updater,
                        QDO.modifyTime
                ))
                .from(QDO)
                .where(QDO.appCode.eq(param.get("appCode").toString()).and(QDO.udcCode.eq(param.get("udcCode").toString())))
                .fetch();
    }
}
